@@ -39,6 +39,12 @@ class Plugin(Plugin_Base):
         self.config.update(config)
         self.logger.i("-- plugin <{}> init".format(self.name))
         self.logger.i("-- plugin <{}> config: {}".format(self.name, self.config))
+
+    def on_new_process_init(self):
+        '''
+            for multiple processing, for below func, will be called in new process,
+            every time create a new process, this func will be invoke
+        '''
         if mistune_version >= 20:
             self.md_parser = mistune.create_markdown(renderer=MDRenderer(), plugins=plugins)
         else:
@@ -46,6 +52,14 @@ class Plugin(Plugin_Base):
             self.md_parser = mistune.Markdown(renderer=renderer)
         self.meta_parser = Meta_Parser()
 
+    def on_new_process_del(self):
+        '''
+            for multiple processing, for below func, will be called in new process,
+            every time exit a new process, this func will be invoke
+        '''
+        del self.md_parser
+        del self.meta_parser
+
     def on_parse_files(self, files, new_config=None):
         # result, format must be this
         result = {
